@@ -13,7 +13,7 @@ JMX::Jmx4Perl::Product::Jonas - Handler for Jonas
 
 =head1 DESCRIPTION
 
-This is the product handler support Jonas 4.
+This is the product handler support Jonas 4 (L<http://jonas.ow2.org/>)
 
 =cut
 
@@ -29,11 +29,15 @@ sub order {
     return 10;
 }
 
-sub _try_version {
+sub __try_version {
     my $self = shift;
     return $self->try_attribute("version","jonas:j2eeType=J2EEServer,name=jonas","serverVersion");
 }
 
+sub autodetect_pattern {
+    return ("vendor",qr/OW2/i);
+}
+
 sub server_info { 
     my $self = shift;
     my $ret = $self->SUPER::server_info();
@@ -50,7 +54,7 @@ sub init_aliases {
      attributes => 
    {
     #SERVER_ADDRESS => [ "jboss.system:type=ServerInfo", "HostAddress"],
-    SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
+    #SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
    },
      operations => 
    {
